# Hetzner Speed Test

Simple CLI tool to test the latency and download speed of different Hetzner instances.

## Install

The recommended way to install is to use `pipx`:

```pipx install hetzner-speedtest```

## Usage

```hetzner-speedtest```

You can specify a specific region, only test latency or download speed and configure the tests. Use `--help` for more information.
